@@ -17,9 +17,11 @@ void frmLfm::init()
 	lblPassword->setText(i18n("Password"));
 	chkLfm->setText(i18n("support last.fm"));
 	lblWarning->setText("<b><i>" + i18n("Warning") + "</i></b><br>" +
-		i18n("last.fm support violates privacy"));
+		i18n("last.fm support violates privacy") + "!");
 	pshCancel->setText(i18n("Cancel"));
 	setCaption(i18n("last.fm"));
+
+	updatePercent(sldPercent->value());
 }
 
 void frmLfm::acceptTags()
@@ -40,3 +42,8 @@ void frmLfm::rejectTags()
 	ok = false;
 	hide();
 }
+
+void frmLfm::updatePercent(int v)
+{
+	lblPercent->setText(i18n("Playback percent complete") + " (" + QString::number(v) + "%).");
+}
