@@ -7,7 +7,7 @@ void frmPlaylist::init()
 	chkDest->setText(i18n("set as destination"));
 	pshCancel->setText(i18n("Cancel"));
 
-	QToolTip::add(chkDest, i18n("Use Shift+C/S to copy/send track(s)"));
+//	QToolTip::add(chkDest, i18n("Use Shift+C/S to copy/send track(s)"));
 }
 
 void frmPlaylist::acceptPlaylist()
