@@ -4,13 +4,15 @@
 
 **/
 
+#include <qfileinfo.h>
 #include <qmessagebox.h>
+#include <qprocess.h>
 
 #include <klocale.h>
 
 void frmTags::init()
 {
-	lblLocation->setText(i18n("Location"));
+	pshLocation->setText(i18n("Location"));
 	lblTitle->setText(i18n("Title"));
 	lblAlbum->setText(i18n("Album"));
 	lblArtist->setText(i18n("Artist"));
@@ -35,3 +37,13 @@ void frmTags::rejectTags()
 	ok = false;
 	hide();
 }
+
+void frmTags::onLocation()
+{
+	QProcess open_dir;
+	open_dir.addArgument("konqueror");
+	open_dir.addArgument(QFileInfo(txtLocation->text()).dir().path());
+
+	if (!open_dir.start())
+		QMessageBox::information(this, i18n("Info"), i18n("Failed to run Konqueror."));
+}
