@@ -2,6 +2,6 @@
 #define VERSION_H
 
 #define FALF_NAM "FALF Player"
-#define FALF_VER "1.1 Tangerine"
+#define FALF_VER "1.2 Winkle"
 
 #endif
